@@ -18,11 +18,12 @@
 #include <jsoncons/config/compiler_support.hpp>
 #include <jsoncons/json_exception.hpp>
 #include <jsoncons/json_parser.hpp>
+#include <jsoncons/json_type.hpp>
 #include <jsoncons/json_visitor.hpp>
-#include <jsoncons/ser_context.hpp>
+#include <jsoncons/semantic_tag.hpp>
+#include <jsoncons/ser_util.hpp>
 #include <jsoncons/source.hpp>
 #include <jsoncons/source_adaptor.hpp>
-#include <jsoncons/tag_type.hpp>
 #include <jsoncons/utility/unicode_traits.hpp>
 
 namespace jsoncons {
@@ -165,7 +166,7 @@ namespace jsoncons {
         }
     };
 
-    template <typename CharT,typename Source=jsoncons::stream_source<CharT>,typename TempAllocator =std::allocator<char>>
+    template <typename CharT,typename Source=jsoncons::stream_source<CharT>,typename TempAlloc =std::allocator<char>>
     class basic_json_reader 
     {
     public:
@@ -173,14 +174,14 @@ namespace jsoncons {
         using source_type = Source;
         using string_view_type = jsoncons::basic_string_view<CharT>;
     private:
-        using char_allocator_type = typename std::allocator_traits<TempAllocator>:: template rebind_alloc<CharT>;
+        using char_allocator_type = typename std::allocator_traits<TempAlloc>:: template rebind_alloc<CharT>;
 
         static constexpr size_t default_max_buffer_size = 16384;
 
         json_source_adaptor<Source> source_;
         basic_default_json_visitor<CharT> default_visitor_;
         basic_json_visitor<CharT>& visitor_;
-        basic_json_parser<CharT,TempAllocator> parser_;
+        basic_json_parser<CharT,TempAlloc> parser_;
 
         // Noncopyable and nonmoveable
         basic_json_reader(const basic_json_reader&) = delete;
@@ -188,7 +189,7 @@ namespace jsoncons {
 
     public:
         template <typename Sourceable>
-        explicit basic_json_reader(Sourceable&& source, const TempAllocator& temp_alloc = TempAllocator())
+        explicit basic_json_reader(Sourceable&& source, const TempAlloc& temp_alloc = TempAlloc())
             : basic_json_reader(std::forward<Sourceable>(source),
                                 default_visitor_,
                                 basic_json_decode_options<CharT>(),
@@ -200,7 +201,7 @@ namespace jsoncons {
         template <typename Sourceable>
         basic_json_reader(Sourceable&& source, 
                           const basic_json_decode_options<CharT>& options, 
-                          const TempAllocator& temp_alloc = TempAllocator())
+                          const TempAlloc& temp_alloc = TempAlloc())
             : basic_json_reader(std::forward<Sourceable>(source),
                                 default_visitor_,
                                 options,
@@ -212,7 +213,7 @@ namespace jsoncons {
         template <typename Sourceable>
         basic_json_reader(Sourceable&& source,
                           std::function<bool(json_errc,const ser_context&)> err_handler, 
-                          const TempAllocator& temp_alloc = TempAllocator())
+                          const TempAlloc& temp_alloc = TempAlloc())
             : basic_json_reader(std::forward<Sourceable>(source),
                                 default_visitor_,
                                 basic_json_decode_options<CharT>(),
@@ -225,7 +226,7 @@ namespace jsoncons {
         basic_json_reader(Sourceable&& source, 
                           const basic_json_decode_options<CharT>& options,
                           std::function<bool(json_errc,const ser_context&)> err_handler, 
-                          const TempAllocator& temp_alloc = TempAllocator())
+                          const TempAlloc& temp_alloc = TempAlloc())
             : basic_json_reader(std::forward<Sourceable>(source),
                                 default_visitor_,
                                 options,
@@ -237,7 +238,7 @@ namespace jsoncons {
         template <typename Sourceable>
         basic_json_reader(Sourceable&& source, 
                           basic_json_visitor<CharT>& visitor, 
-                          const TempAllocator& temp_alloc = TempAllocator())
+                          const TempAlloc& temp_alloc = TempAlloc())
             : basic_json_reader(std::forward<Sourceable>(source),
                                 visitor,
                                 basic_json_decode_options<CharT>(),
@@ -250,7 +251,7 @@ namespace jsoncons {
         basic_json_reader(Sourceable&& source, 
                           basic_json_visitor<CharT>& visitor,
                           const basic_json_decode_options<CharT>& options, 
-                          const TempAllocator& temp_alloc = TempAllocator())
+                          const TempAlloc& temp_alloc = TempAlloc())
             : basic_json_reader(std::forward<Sourceable>(source),
                                 visitor,
                                 options,
@@ -263,7 +264,7 @@ namespace jsoncons {
         basic_json_reader(Sourceable&& source,
                           basic_json_visitor<CharT>& visitor,
                           std::function<bool(json_errc,const ser_context&)> err_handler, 
-                          const TempAllocator& temp_alloc = TempAllocator())
+                          const TempAlloc& temp_alloc = TempAlloc())
             : basic_json_reader(std::forward<Sourceable>(source),
                                 visitor,
                                 basic_json_decode_options<CharT>(),
@@ -277,7 +278,7 @@ namespace jsoncons {
                           basic_json_visitor<CharT>& visitor, 
                           const basic_json_decode_options<CharT>& options,
                           std::function<bool(json_errc,const ser_context&)> err_handler, 
-                          const TempAllocator& temp_alloc = TempAllocator())
+                          const TempAlloc& temp_alloc = TempAlloc())
            : source_(std::forward<Sourceable>(source)),
              visitor_(visitor),
              parser_(options,err_handler,temp_alloc)
